from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Int, Float, Boolean, String, File

Biscuit_Align_V0_1_0 = CommandToolBuilder(tool="biscuit_align", base_command=["biscuit", "align"], inputs=[ToolInput(tag="in_number_of_threads", input_type=Int(optional=True), prefix="-t", doc=InputDocumentation(doc="number of threads [1]")), ToolInput(tag="in_pe_read_read", input_type=Int(optional=True), prefix="-b", doc=InputDocumentation(doc="For PE, read 1 to parent, read 2 to daughter (1, directional library);\nread1 and read 2 to both (0: default, nondirectional library); For SE, parent (1);\ndaughter (3); both (0, default); Def: parent (bisulfite\ntreated strand), daughter (synthesized strand)")), ToolInput(tag="in_bsw_strand_strand", input_type=Int(optional=True), prefix="-f", doc=InputDocumentation(doc="1: BSW strand; 3: BSC strand; 0 (default): both; (libraries\ntargeting either BSW or BSC are unseen so far!)")), ToolInput(tag="in_minimum_seed_length", input_type=Int(optional=True), prefix="-k", doc=InputDocumentation(doc="minimum seed length [19]")), ToolInput(tag="in_band_width_banded", input_type=Int(optional=True), prefix="-w", doc=InputDocumentation(doc="band width for banded alignment [100]")), ToolInput(tag="in_offdiagonal_xdropoff", input_type=Int(optional=True), prefix="-d", doc=InputDocumentation(doc="off-diagonal X-dropoff [100]")), ToolInput(tag="in_look_internal_float", input_type=Float(optional=True), prefix="-r", doc=InputDocumentation(doc="look for internal seeds inside a seed longer than\n{-k} * FLOAT [1.5]")), ToolInput(tag="in_seed_occurrence_round", input_type=Int(optional=True), prefix="-y", doc=InputDocumentation(doc="seed occurrence for the 3rd round seeding [20]")), ToolInput(tag="in_var_8", input_type=Int(optional=True), prefix="-J", doc=InputDocumentation(doc="adaptor of read 1 (fastq direction)")), ToolInput(tag="in_var_9", input_type=Int(optional=True), prefix="-K", doc=InputDocumentation(doc="adaptor of read 2 (fastq direction)")), ToolInput(tag="in_min_base_quality", input_type=Int(optional=True), prefix="-z", doc=InputDocumentation(doc="min base quality to keep from both ends of reads [0]")), ToolInput(tag="in_five", input_type=Int(optional=True), prefix="-5", doc=InputDocumentation(doc="number of extra bases to clip from 5'-end [0]")), ToolInput(tag="in_three", input_type=Int(optional=True), prefix="-3", doc=InputDocumentation(doc="number of extra bases to clip from 3'-end [0]")), ToolInput(tag="in_skip_seeds_more", input_type=Int(optional=True), prefix="-c", doc=InputDocumentation(doc="skip seeds with more than INT occurrences [500]")), ToolInput(tag="in_drop_chains_shorter", input_type=Float(optional=True), prefix="-D", doc=InputDocumentation(doc="drop chains shorter than FLOAT fraction of the longest\noverlapping chain [0.50]")), ToolInput(tag="in_discard_chain_seeded", input_type=Int(optional=True), prefix="-W", doc=InputDocumentation(doc="discard a chain if seeded bases shorter than INT [0]")), ToolInput(tag="in_perform_most_rescues", input_type=Int(optional=True), prefix="-m", doc=InputDocumentation(doc="perform at most INT rounds of mate rescues for a read [50]")), ToolInput(tag="in_skip_mate_rescue", input_type=Boolean(optional=True), prefix="-S", doc=InputDocumentation(doc="skip mate rescue")), ToolInput(tag="in_skip_pairing_rescue", input_type=Boolean(optional=True), prefix="-P", doc=InputDocumentation(doc="skip pairing; mate rescue performed unless -S also in use")), ToolInput(tag="in_discard_fulllength_exact", input_type=Boolean(optional=True), prefix="-e", doc=InputDocumentation(doc="discard full-length exact matches")), ToolInput(tag="in_score_sequence_match", input_type=Int(optional=True), prefix="-A", doc=InputDocumentation(doc="score for a sequence match, which scales options -TdBOELU\nunless overridden [1]")), ToolInput(tag="in_penalty_for_mismatch", input_type=Int(optional=True), prefix="-B", doc=InputDocumentation(doc="penalty for a mismatch [2]")), ToolInput(tag="in_gap_open_penalties", input_type=Int(), prefix="-O", doc=InputDocumentation(doc="gap open penalties for deletions and insertions [6,6]")), ToolInput(tag="in_gap_extension_penalty", input_type=Int(), prefix="-E", doc=InputDocumentation(doc="gap extension penalty; a gap of size k cost\n'{-O} + {-E}*k' [1,1]")), ToolInput(tag="in_penalty_end_clipping", input_type=Int(), prefix="-L", doc=InputDocumentation(doc="penalty for 5'- and 3'-end clipping [10,10]")), ToolInput(tag="in_penalty_unpaired_read", input_type=Int(optional=True), prefix="-U", doc=InputDocumentation(doc="penalty for an unpaired read pair [17]")), ToolInput(tag="in_turn_autoinference_alt", input_type=Boolean(optional=True), prefix="-i", doc=InputDocumentation(doc="turn off autoinference of ALT chromosomes.")), ToolInput(tag="in_smart_pairing_ignoring", input_type=Boolean(optional=True), prefix="-p", doc=InputDocumentation(doc="smart pairing (ignoring in2.fq)")), ToolInput(tag="in_read_group_line", input_type=String(optional=True), prefix="-R", doc=InputDocumentation(doc="read group header line such as '@RG\tID:foo\tSM:bar' [null]")), ToolInput(tag="in_suppress_sam_header", input_type=Boolean(optional=True), prefix="-F", doc=InputDocumentation(doc="suppress SAM header output")), ToolInput(tag="in_file_insert_str", input_type=File(optional=True), prefix="-H", doc=InputDocumentation(doc="/FILE   insert STR to header if it starts with @; or insert lines\nin FILE [null]")), ToolInput(tag="in_treat_alt_contigs", input_type=Boolean(optional=True), prefix="-j", doc=InputDocumentation(doc="treat ALT contigs as part of the primary assembly (i.e.\nignore <idxbase>.alt file)")), ToolInput(tag="in_modify_mapq_supplementary", input_type=Boolean(optional=True), prefix="-q", doc=InputDocumentation(doc="don't modify mapQ of supplementary alignments.")), ToolInput(tag="in_verbose_levelerror_warning", input_type=Int(optional=True), prefix="-v", doc=InputDocumentation(doc="verbose level:\n1=error, 2=warning, 3=message, 4+=debugging [3]")), ToolInput(tag="in_minimum_score_output", input_type=Int(optional=True), prefix="-T", doc=InputDocumentation(doc="minimum score to output [30]")), ToolInput(tag="in_maximum_number_hits", input_type=Int(), prefix="-h", doc=InputDocumentation(doc="maximum number of hits output in XA [5,5]")), ToolInput(tag="in_output_alignments_pe", input_type=Boolean(optional=True), prefix="-a", doc=InputDocumentation(doc="output all alignments for SE or unpaired PE")), ToolInput(tag="in_append_fastafastq_comment", input_type=Boolean(optional=True), prefix="-C", doc=InputDocumentation(doc="append FASTA/FASTQ comment to SAM output")), ToolInput(tag="in_output_reference_header", input_type=Boolean(optional=True), prefix="-V", doc=InputDocumentation(doc="output the reference FASTA header in the XR tag")), ToolInput(tag="in_use_soft_clipping", input_type=Boolean(optional=True), prefix="-Y", doc=InputDocumentation(doc="use soft clipping for supplementary alignments")), ToolInput(tag="in_mark_shorter_hits", input_type=Boolean(optional=True), prefix="-M", doc=InputDocumentation(doc="mark shorter split hits as secondary")), ToolInput(tag="in_specify_mean_deviation", input_type=Float(), prefix="-I", doc=InputDocumentation(doc="specify the mean, standard deviation (10% of the mean\nif absent), max (4 sigma from the mean if absent) and min\nof insert size distribution.FR orientation only [inferred]\n")), ToolInput(tag="in_idx_base", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_in_one_dot_fq", input_type=Int(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_in_two_dot_fq", input_type=Int(optional=True), position=2, doc=InputDocumentation(doc=""))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Biscuit_Align_V0_1_0().translate("wdl", allow_empty_container=True)

